# 444 evidence

**Description:** Gathers evidence and verifies facts. The "evidence" stage compiles supporting data or examples to ensure that conclusions are well-founded.

**Usage:** `444 evidence`

This stage adds fact-checks, data, or references to support the reasoning.
